import { View } from '@tarojs/components'
import React, { useCallback, memo, useEffect, useMemo, useRef, useState, ReactNode, forwardRef, useImperativeHandle } from 'react'
import styles from "./index.module.scss"
import classnames from "classnames";
import Taro, { usePullDownRefresh, useRouter, useDidShow } from '@tarojs/taro';
import { alert } from '@/common/common'
import { formatPriceDiv, formatDateTime, formatWeightDiv } from '@/common/format'
import DropDownItem from '@/components/dropDown-item'
interface Props {
    handSort?: (any) => void,
    value?: any,
    onCloseOverlay?: () => void
}

type ListType = {
    name: string,
    id: string,
    checked: boolean
}

export default memo(forwardRef((props: Props, ref) => {

    const DropDownItemRef = useRef<any>()
    useImperativeHandle(
        ref,
        () => {
            return {
                show: DropDownItemRef?.current?.show,
                showPopup: DropDownItemRef?.current.showPopup,
                closePopup: DropDownItemRef?.current?.closePopup,
            }
        },
        [DropDownItemRef?.current],
    )


    const [list, setlist] = useState<ListType[]>([
        {
            name: '下单时间正序',
            id: '1',
            checked: false
        },
        {
            name: '创建时间正序',
            id: '2',
            checked: false
        },
        {
            name: '更新时间正序',
            id: '3',
            checked: false
        },
        {
            name: '下单时间倒序',
            id: '-1',
            checked: false
        },
        {
            name: '创建时间倒序',
            id: '-2',
            checked: false
        },
        {
            name: '更新时间倒序',
            id: '-3',
            checked: false
        }
    ])

    const [currentValue, setCurrentValue] = useState<number>(-1)

    const handItem = (it) => {
        list.map(item => {
            if (item.id == it.id) {
                item.checked = true
            } else {
                item.checked = false
            }
            return item
        })
        setlist([...list])
        props.handSort?.(it.id)
    }


    const title = useMemo(() => {
        let arr = list.filter(item => { return item.checked })
        if (!arr.length) {
            return '默认排序'
        } else {
            return arr[0]?.name
        }
    }, [list])


    return (
        <DropDownItem ref={DropDownItemRef} title={title} value={currentValue} activeColor='#337fff' onCloseOverlay={props?.onCloseOverlay}>
            <View className={styles.mainBox}>
                {
                    list.map((item, index) => {
                        return (
                            <View className={classnames(item.checked ? styles.itemactiveFlex : styles.itemFlex)} onClick={() => handItem?.(item)}>{item.name}</View>
                        )
                    })
                }
            </View>
        </DropDownItem>
    )
}))